{ pkgs, ... }:
{
	networking.wireless.iwd = {
		enable = true;
		settings = {
			General = {
				AddressRandomization = "network";
				# EnableNetworkConfiguration = false;

				RoamThreshold = -70;
				RoamThreshold5G = -90;
				RoamRetryInterval = 10;
			};
			# Network.EnableIPv6 = true;

			Rank.BandModifier5Ghz = 5.0;
			# Scan.DisablePeriodicScan = true;
		};
	};

	systemd.network.networks.wifi = {
		matchConfig = {
			Name = "wlan0";
			SSID = "!HotoHo-v6";
		};
		DHCP = "ipv4";
		networkConfig = {
			IPv6AcceptRA = true;
			IPv6PrivacyExtensions = true;
		};
	};
	systemd.network.networks.wifi-v6 = {
		matchConfig = {
			Name = "wlan0";
			SSID = "HotoHo-v6";
		};
		networkConfig = {
			DNSSEC = false;
			IPv6AcceptRA = true;
			IPv6PrivacyExtensions = true;
		};
	};
	systemd.network.networks.eth = {
		matchConfig.Name = "enp*";
		DHCP = "ipv4";
		networkConfig = {
			IPv6AcceptRA = true;
			IPv6PrivacyExtensions = true;
		};
	};

	hardware.bluetooth.enable = true;
	sound.enable = true;
	hardware.pulseaudio.enable = false; #use pipewire
	services.pipewire = {
		enable = true;
		alsa.enable = true;
		# alsa.support32bit = true;
		pulse.enable = true;
	};

	environment.systemPackages = with pkgs; [
		iw
		pulseaudio-modules-bt
	];

	programs.browserpass.enable = true;

	# smartcard
	services.pcscd.enable = true;
	programs.gnupg.agent = {
		enable = true;
		enableSSHSupport = true;
		pinentryFlavor = "gnome3";
	};
}
